=============================================
Generating nanostructures (`sknano.nanogen`)
=============================================

.. sectionauthor:: Andrew Merrill <androomerrill@gmail.com>

.. currentmodule:: sknano.nanogen

.. _nanogen-intro:

This tutorial describes the modules available in the
:py:mod:`sknano.nanogen` sub-package.

Structure generators
====================

The :py:mod:`~sknano.nanogen` module provides the following
classes for structure generation:

* :py:class:`~sknano.nanogen.GrapheneGenerator`
* :py:class:`~sknano.nanogen.BiLayerGrapheneGenerator`
* :py:class:`~sknano.nanogen.NanotubeGenerator`
* :py:class:`~sknano.nanogen.TubeGen`
